@@ -36,6 +36,8 @@ file.
 
 	use StreamFinder;
 
+	die "..usage:  $0 URL\n"  unless ($ARGV[0]);
+
 	my $station = new StreamFinder($ARGV[0]);
 
 	die "Invalid URL or no streams found!\n"  unless ($station);
@@ -408,7 +410,7 @@ use strict;
 use warnings;
 use vars qw(@ISA @EXPORT $VERSION);
 
-our $VERSION = '1.34';
+our $VERSION = '1.35';
 our $DEBUG = 0;
 
 require Exporter;
@@ -441,7 +443,7 @@ sub new
 #	} elsif ($haveit{'IHeartRadio'} && $url =~ m#\biheart(?:radio)?\.#i) {
 	if ($haveit{'IHeartRadio'} && $url =~ m#\biheart(?:radio)?\.#i) {
 		return new StreamFinder::IHeartRadio($url, @args);
-	} elsif ($haveit{'Tunein'} && $url =~ m#\btunein\.\/#) {  #NOTE:ALSO USES youtube-dl!
+	} elsif ($haveit{'Tunein'} && $url =~ m#\btunein\.#) {  #NOTE:ALSO USES youtube-dl!
 		return new StreamFinder::Tunein($url, @args);
 	} elsif ($haveit{'RadioNet'} && $url =~ m#\bradio\.net\/#) {
 		return new StreamFinder::RadioNet($url, @args);
@@ -451,17 +453,17 @@ sub new
 		return new StreamFinder::Reciva($url, @args);
 	} elsif ($haveit{'Brighteon'} && $url =~ m#\bbrighteon\.com\/#) {  #NOTE:ALSO USES youtube-dl!
 		return new StreamFinder::Brighteon($url, @args);
-	} elsif ($haveit{'Vimeo'} && $url =~ m#\bvimeo\.\/#) {  #NOTE:ALSO USES youtube-dl!
+	} elsif ($haveit{'Vimeo'} && $url =~ m#\bvimeo\.#) {  #NOTE:ALSO USES youtube-dl!
 		return new StreamFinder::Vimeo($url, @args);
 	} elsif ($haveit{'Apple'} && $url =~ m#\b(?:podcasts?|music)\.apple\.com\/#) {  #NOTE:ALSO USES youtube-dl!
 		return new StreamFinder::Apple($url, @args);
-	} elsif ($haveit{'Spreaker'} && $url =~ m#\.spreaker\.\/#) {
+	} elsif ($haveit{'Spreaker'} && $url =~ m#\.spreaker\.#) {
 		return new StreamFinder::Spreaker($url, @args);
 #	} elsif ($haveit{'Facebook'} && ($url =~ m#^http[s]?\:\/\/\w*\.facebook\.#)) {  #REMOVED SUPPORT AS FB NOW LOCKS YOUR ACCOUNT & FORCES PASSWORD CHANGE!
 #		return new StreamFinder::Facebook($url, @args);
-	} elsif ($haveit{'Bitchute'} && $url =~ m#\.bitchute\.\/#) {  #DEFAULT TO youtube-dl SINCE SO MANY URLS ARE HANDLED THERE NOW.
+	} elsif ($haveit{'Bitchute'} && $url =~ m#\.bitchute\.#) {  #DEFAULT TO youtube-dl SINCE SO MANY URLS ARE HANDLED THERE NOW.
 		return new StreamFinder::Bitchute($url, @args);
-	} elsif ($haveit{'Blogger'} && $url =~ m#\.blogger\.\/#) {  #DEFAULT TO youtube-dl SINCE SO MANY URLS ARE HANDLED THERE NOW.
+	} elsif ($haveit{'Blogger'} && $url =~ m#\.blogger\.#) {  #DEFAULT TO youtube-dl SINCE SO MANY URLS ARE HANDLED THERE NOW.
 		return new StreamFinder::Blogger($url, @args);
 	} elsif ($haveit{'Castbox'} && $url =~ m#\bcastbox\.\w+\/#) {  #DEFAULT TO youtube-dl SINCE SO MANY URLS ARE HANDLED THERE NOW.
 		return new StreamFinder::Castbox($url, @args);
