@@ -19,11 +19,15 @@ file.
 
 =head1 SYNOPSIS
 
+	#!/usr/bin/perl
+
 	use strict;
 
 	use StreamFinder::Apple;
 
-	my $podcast = new StreamFinder::Apple(<url>);
+	die "..usage:  $0 URL\n"  unless ($ARGV[0]);
+
+	my $podcast = new StreamFinder::Apple($ARGV[0]);
 
 	die "Invalid URL or no streams found!\n"  unless ($podcast);
 
