@@ -18,11 +18,15 @@ file.
 
 =head1 SYNOPSIS
 
+	#!/usr/bin/perl
+
 	use strict;
 
 	use StreamFinder::Castbox;
 
-	my $podcast = new StreamFinder::Castbox(<url>);
+	die "..usage:  $0 URL\n"  unless ($ARGV[0]);
+
+	my $podcast = new StreamFinder::Castbox($ARGV[0]);
 
 	die "Invalid URL or no streams found!\n"  unless ($podcast);
 
